/**
 專案名稱 : PIC32MM Lab3_ADC1 Convert.x 
 主要功能 : 使用 MCC v3.15 來規劃 ADC1 做 12-bit 轉換功能，將其轉換後的值
 以 Hex 的格式顯示在 LCD 的第二行

  軟體版本:
        Product Revision  :  MPLAB(c) Code Configurator - 3.15.0
        Device            :  PIC32MM0064GPL036
        Compiler          :  XC32 1.42
        MPLAB             :  MPLAB X 3.35
*/

/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. 

    本軟體是由 Microchip 公司所提供的範例程式。 Microchip 不保證其功能性的完整，
    且本範例程式僅是用來展示其功能，對於任何侵權或相關版權及軟體的錯誤所導致損失
    ，損害，費用和開支等 Microchip 均不具賠償責任。

    注意 : 您必須接收上述條款後方能使用此範例程式。
*/

/*  關於使用 MCC v3.15 設定 PIC32MM064GPL036 ADC1 的一些重要問題。ADC1 設設定是
    採用自動取樣手動轉換的方式，PBCLK 為 24MHz 在 Data Sheet 裡有標明: 12-bit 最小
    Tad 為 280nS，10-bit 時的 Tad 最小需求為 200nS。所以範例中設定為 1uS 的 Tad. 
    注意: 請不要使用 8MHz 的 FRC 選項，因為這時 Tad 會無法設定造成轉換上的錯誤。
*/

#include "mcc_generated_files/mcc.h"
#include "lcd.h"                    // LCD 函數原型宣告
#include <stdio.h>                  // 使用到 itoa() 函數
 
volatile unsigned int LCD_Update;   // LCD 顯示用旗號，Timer1 中斷時使用
char Disp_String[6];                // itoa() 轉換後的儲存陣列

union{
    unsigned int AD_10bit;
    struct{
        unsigned char AD_LSB;
        unsigned char AD_MSB;
    }AD_Byte;
} ADC_Result;
 
const char * Disp_Line[4] =         // 在 Flash 所宣告的 LCD 顯示資料
{                                   // 使用指標陣列方式宣告
    "Read VR Voltage " ,
    " Press SW1 ...  " ,
    "Lab3 ADC1 Conver" ,
    "ADC1 = 0x           " ,    
};

void main(void)
{
    // initialize the device
    SYSTEM_Initialize();

    // When using interrupts, you need to set the Global Interrupt Enable bits
    // Use the following macros to:

    // Enable the Global Interrupts
    INTERRUPT_GlobalEnable();

    // Disable the Global Interrupts
    //INTERRUPT_GlobalDisable();
    
    
    LCD_Initialize( );              // LCD 模組初始設定 (4-bit Mode)
    
    LCD_Set_Cursor(0,0);            // LCD 游標在(0,0) 位置
    putrsLCD(Disp_Line[0]);         // 顯示 "PIC32MM LCD Demo"
    LCD_Set_Cursor(1,0);            // LCD 游標在第二行第一個位置
    putrsLCD(Disp_Line[1]);         // 顯示  " Press SW1 ...  " 
    
    while(SW1_GetValue());           // 等待 SW1被按下
                                    // S3_GetValue() 在 pin_manager.h 裡宣告
    LCD_Set_Cursor(0,0);
    putrsLCD(Disp_Line[2]);         // 顯示 "Lab2 LCD Display"
    LCD_Set_Cursor(1,0);
    putrsLCD(Disp_Line[3]);         // 顯示 "Time =          "
    
    LCD_Update = 0 ;

    while(1)
    {
        
        if (LCD_Update)                 // 檢查 0.4S 的計時到了嗎?
        {                               // 是，0.4S 已到，更新 LCD 的顯示
            LCD_Update = 0;
                                        // 讀取可變電阻上的轉換值
            ADC_Result.AD_10bit = ADC_Read10bit ( ADC1_CHANNEL_AN12 );
        
            LCD_Set_Cursor(1,7);        // LCD 游標移到第二行第八個位置
            putcLCD('0');
            putcLCD('x');
            puthexLCD(ADC_Result.AD_Byte.AD_MSB);  // 以 Hex 格式顯示 ADC 轉換結果
            puthexLCD(ADC_Result.AD_Byte.AD_LSB);
        }
    }
}
/**
 End of File
*/