/******************************************************************************
Software License Agreement

 
    (c) 2016 Microchip Technology Inc. and its subsidiaries. 

    本軟體是由 Microchip 公司所提供的範例程式。 Microchip 不保證其功能性的完整，
    且本範例程式僅是用來展示其功能，對於任何侵權或相關版權及軟體的錯誤所導致損失
    ，損害，費用和開支等 Microchip 均不具賠償責任。

    注意 : 您必須接收上述條款後方能使用此範例程式。
 
*******************************************************************************/
#include <xc.h>
#include <stdint.h>
#include <stdbool.h>
#include "mcc_generated_files/mcc.h"


 /*********************************************************************
 * 函數 : ADC_Read10bit(ADC_CHANNEL channel);
 *
 * 說明 : 讀取所設定 ADC 輸入通道 (AN12, RC0) 可變電阻上的數值後傳回 10-bit 的轉換數值
 *
 * 輸入 : ADC_CHANNEL channel - 使用列舉方式宣告 (adc1.h) 輸入的通道列舉成員識別字
 *        可變電阻接至 AN12 (RC0)。
 typedef enum 
{
    ADC1_CHANNEL_AN12 =  0xC,
    ADC1_CHANNEL_AVSS =  0xD,
    ADC1_CHANNEL_AVDD =  0xE,
    ADC1_CHANNEL_VBG =  0x1C,
    ADC1_MAX_CHANNEL_COUNT = 4
} ADC1_CHANNEL;
 
 *
 * 輸出 : uint16_t 向右靠齊的 10-bit 的 ADC 轉換值 或 錯誤值 0xFFFF
 *
 ********************************************************************/
uint16_t ADC_Read10bit ( ADC1_CHANNEL channel  )
{
    uint16_t i ;

    switch (channel)
    {
        case ADC1_CHANNEL_AN12:     // 判斷傳入的 ADC1 轉換通道為 CH12 
            break ;

        default:                    // 傳入的轉換定義參數錯誤，回傳 0xFFFF
            return 0xFFFF ;
    }

    ADC1_ChannelSelect(channel) ;   // 設定 ADC1 轉換的通道

    // Get an ADC sample
    ADC1_Start();                   // 手動取樣
    for (i = 0 ; i < 1000 ; i++) ;  // 取樣延遲
    ADC1_Stop();                    // 結束取樣，ADC1 開始轉換

    while(!ADC1_IsConversionComplete()) ;       // 等待 ADC1 轉換完成 (AD1CON1bits.DONE == 0)

    return ADC1BUF0 ;
}     

/*********************************************************************
    使用 UART 傳送資料函數，這些函數採用 VT100 的命令格式
    傳送方式使用最基本的傳輸暫存器 (U2TXREG) 的方式，且不使用傳輸中斷
*********************************************************************/
// 送出終端機換行及歸零的命令
void Send_CR_LF(void)
{
		while (! IFS1bits.U2TXIF);
		U2TXREG = '\n';
		while (! IFS1bits.U2TXIF);
		U2TXREG = '\r';
}

// 清除終端機螢幕
void VT100_Clear_Screen(void)  // Send "ESC [ 2 J " to UART
{
    while (! IFS1bits.U2TXIF);
	U2TXREG ='\x1b';
	while (! IFS1bits.U2TXIF);
	U2TXREG = '[';
 
	while (! IFS1bits.U2TXIF);
	U2TXREG = '2';
	while (! IFS1bits.U2TXIF);
	U2TXREG = 'J'; 
}

// 在終端機上顯示 Byte 轉成 ASCII Code 的 Hex 的字元
void VT100_puthex(unsigned char HEX_Val)
{
	unsigned char Temp_HEX ;

	Temp_HEX = (HEX_Val >> 4) & 0x0f ;

	if ( Temp_HEX > 9 )Temp_HEX += 0x37 ;
    else Temp_HEX += 0x30 ;
	while (! IFS1bits.U2TXIF);
	U2TXREG = Temp_HEX ;

	Temp_HEX = HEX_Val  & 0x0f ;
	if ( Temp_HEX > 9 )Temp_HEX += 0x37 ;
    else Temp_HEX += 0x30 ;
	while (! IFS1bits.U2TXIF);
	U2TXREG = Temp_HEX ;
}

