/**
 專案名稱 : PIC32MM Lab4_UARTt.x 
 主要功能 : 延續 Lab3 讀取 ADC1 的功能及 LCD 顯示功能外，加入了終端機顯示 ADC1 的轉換值

  軟體版本:
        Product Revision  :  MPLAB(c) Code Configurator - 3.15.0
        Device            :  PIC32MM0064GPL036
        Compiler          :  XC32 1.42
        MPLAB             :  MPLAB X 3.35
*/

/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. 

    本軟體是由 Microchip 公司所提供的範例程式。 Microchip 不保證其功能性的完整，
    且本範例程式僅是用來展示其功能，對於任何侵權或相關版權及軟體的錯誤所導致損失
    ，損害，費用和開支等 Microchip 均不具賠償責任。

    注意 : 您必須接收上述條款後方能使用此範例程式。
*/

/*  關於使用 MCC v3.15 設定 PIC32MM064GPL036 ADC1 的一些重要問題。ADC1 設設定是
    採用自動取樣手動轉換的方式，PBCLK 為 24MHz 在 Data Sheet 裡有標明: 12-bit 最小
    Tad 為 280nS，10-bit 時的 Tad 最小需求為 200nS。所以範例中設定為 1uS 的 Tad. 
    注意: 請不要使用 8MHz 的 FRC 選項，因為這時 Tad 會無法設定造成轉換上的錯誤。
 
    注意 : UART 使用 MCC 所產生的 UART2_Initialize 函數來做初始設定，發送功能沒有用到
    中斷傳送方式，而使用一般的暫存器值接傳送及 printf( ) 的方式。 
 
 　 1. 因為在 MCC UART2 的設定裡使用中斷模式，所以接收及傳送的中斷功能都會被開啟，因此將無法使用
       printf( )。所以在本 Lab4 的練習是用手動方式在 UART2_Initialize ( ) 函數裡關閉 IEC1bits.U2TXIE
       這樣才能使用 printf() 的方式傳送。
    2. 接收仍舊維持使用接收中斷方式以確保接收的即時性，範例仍使用 MCC 所產生的接收函數。
       先檢查接緩衝器是否有資料存放後再取走資料。
    3. 測試接收時，請先選擇到 Tera Term 的動作畫面後再輸入鍵盤資料。
  
       UART2 的傳輸速率 : 19200bps。格式為: N, 8 ,1 。 不使用 RTC/CTS 流量控制。
*/

#include "mcc_generated_files/mcc.h"
#include "lcd.h"                    // LCD 函數原型宣告
#include "App.h"
#include <stdio.h>                  // 使用到 itoa() 函數
 
volatile unsigned int LCD_Update;   // LCD 顯示用旗號，Timer1 中斷時使用
char Disp_String[6];                // itoa() 轉換後的儲存陣列
char Received_Data;                 // UART2 接收的暫存資料 (中斷接收))

union{                              // 規劃 ADC1 轉換逤使用的共用變數的宣告
    unsigned int AD_10bit;          // 儲存 12-bit ADC1 的轉換值
    struct{
        unsigned char AD_LSB;       // 分割 12-bit ADC1 MSB 的值
        unsigned char AD_MSB;       // 分割 12-bit ADC1 LSB 的值
    }AD_Byte;
} ADC_Result;
 
const char * Disp_Line[4] =         // 在 Flash 所宣告的 LCD 顯示資料
{                                   // 使用指標陣列方式宣告
    "UART Application" ,
    " Press SW1...   " ,
    "Lab4 Test UART2 " ,
    "ADC1 =          ",
};

const char * TER_Line[4] =         // 在 Flash 所宣告的 Terminal 顯示資料
{                                   // 使用指標陣列方式宣告
    "Clear Terminal Screen",
    "Press SW1 to Continue ...  ",
    "Read the Potentiometer (AN12) = ",
    "UART2 received a Character = ",
};


void main(void)
{
    // initialize the device
    SYSTEM_Initialize();

    // When using interrupts, you need to set the Global Interrupt Enable bits
    // Use the following macros to:

    // Enable the Global Interrupts
    INTERRUPT_GlobalEnable();           // 開啟 Global 中斷 (需關閉 U2TXIE 的中斷)

    // Disable the Global Interrupts
    //INTERRUPT_GlobalDisable();
    
    VT100_Clear_Screen( );          // 清除終端機畫面
    
    LCD_Initialize( );              // LCD 模組初始設定 (4-bit Mode)
    
    LCD_Set_Cursor(0,0);            // LCD 游標在(0,0) 位置
    putrsLCD(Disp_Line[0]);         // LCD 顯示 "UART Application"
    LCD_Set_Cursor(1,0);            // LCD 游標在第二行第一個位置
    putrsLCD(Disp_Line[1]);         // LCD 顯示  "  Press S3 ...  " 
    
    Send_CR_LF( );                  // 在終端機顯示 "Clear Terminal Screen",
    printf(TER_Line[0]);
    Send_CR_LF( );                  // 在終端機顯示 "Press S3 to Continue ...  ",
    printf(TER_Line[1]);
    Send_CR_LF( );
        
    while(SW1_GetValue());          // 等待 SW1 被按下
                                    // S3_GetValue() 在 pin_manager.h 裡宣告
    LCD_Set_Cursor(0,0);
    putrsLCD(Disp_Line[2]);         // LCD 顯示 "Lab4 Test UART2 "
    LCD_Set_Cursor(1,0);
    putrsLCD(Disp_Line[3]);         // LCD 顯示 "ADC1 =          "
    
    LCD_Update = 0 ;

    while(1)
    {
    // 檢查接收狀態
        if (!UART2_ReceiveBufferIsEmpty())              // 檢查接收 Buffer 是否有資料? 
        {
            Received_Data = UART2_Read();               // 讀取接收 Buffer 一個 Byte 的資料
            printf (TER_Line[3]);                       // 先送出 "UART2 received a Character = " 到終端機
            U2TXREG = Received_Data;                    // 送出所接收到的資料到終端機顯示
            Send_CR_LF( );                              // 送出終端機換行及歸零命令
        }    
    // 定期送出 LCD 的更新及終端機的更新顯示        
        if (LCD_Update)                                 // 檢查 0.5S 的計時到了嗎?
        {                                               // 是，0.5S 已到，更新 LCD 的顯示
            LCD_Update = 0;
                                                        // 讀取可變電阻上的轉換值
            ADC_Result.AD_10bit = ADC_Read10bit ( ADC1_CHANNEL_AN12 );
        
            LCD_Set_Cursor(1,7);                        // LCD 游標移到第二行第八個位置
            putcLCD('0');
            putcLCD('x');
            puthexLCD(ADC_Result.AD_Byte.AD_MSB);       // 以 Hex 格式顯示 ADC 轉換結果
            puthexLCD(ADC_Result.AD_Byte.AD_LSB);
            
            printf (TER_Line[2]);                       // 顯示  "Read the Potentiometer (AN12) = " 
            VT100_puthex(ADC_Result.AD_Byte.AD_MSB);    // 以 Hex 格式在終端機顯示 ADC 轉換結果
            VT100_puthex(ADC_Result.AD_Byte.AD_LSB);
            Send_CR_LF( );                              // 送出終端機換行及歸零命令
        }
    }
}
/**
 End of File
*/