/**
 專案名稱 : PIC32MM Lab5-2_SCCP 16-bit Timer
 主要功能 : 將 SCCP3 設定為 16-bit Timer Mode。範例中將 SCCP3 設成 3mS 的計時器
           ，其中斷位元為 CCT3IF (Timer Mode)。本程式藉由這 3mS 的中斷計時做鍵盤
            的背景掃描及處理彈跳問題。

  軟體版本:
        Product Revision  :  MPLAB(c) Code Configurator - 3.15.0
        Device            :  PIC32MM0064GPL036
        Compiler          :  XC32 1.42
        MPLAB             :  MPLAB X 3.35
*/

/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. 

    本軟體是由 Microchip 公司所提供的範例程式。 Microchip 不保證其功能性的完整，
    且本範例程式僅是用來展示其功能，對於任何侵權或相關版權及軟體的錯誤所導致損失
    ，損害，費用和開支等 Microchip 均不具賠償責任。

    注意 : 您必須接收上述條款後方能使用此範例程式。
*/

#include "mcc_generated_files/mcc.h"
#include "lcd.h"                    // LCD 函數原型宣告
#include <stdio.h>                  // 使用到 itoa() 函數

unsigned int Timer_Counter ;        // 時間計數器。
volatile unsigned int LCD_Update;   // LCD 顯示用旗號，Timer1 中斷時使用
char Disp_String[6];                // itoa() 轉換後的儲存陣列

unsigned char debounce = 0;
unsigned char SW_Input = 0;
unsigned char LCD_Course = 0;
 
const char * Disp_Line[4] =         // 在 Flash 所宣告的 LCD 顯示資料
{                                   // 使用指標陣列方式宣告
    "PIC32MM SCCP TMR" ,
    " Press SW1...   " ,
    "Please press key" ,
    "Time =          " ,    
};

void main(void)
{
    // initialize the device
    SYSTEM_Initialize();

    // When using interrupts, you need to set the Global Interrupt Enable bits
    // Use the following macros to:

    // Enable the Global Interrupts
    INTERRUPT_GlobalEnable();

    // Disable the Global Interrupts
    //INTERRUPT_GlobalDisable();
    
    LCD_Initialize( );              // LCD 模組初始設定 (4-bit Mode)
    
    LCD_Set_Cursor(0,0);            // LCD 游標在(0,0) 位置
    putrsLCD(Disp_Line[0]);         // 顯示 "PIC32MM LCD Demo"
    LCD_Set_Cursor(1,0);            // LCD 游標在第二行第一個位置
    putrsLCD(Disp_Line[1]);         // 顯示  "  Press S3 ...  " 
    
    while(SW1_GetValue());           // 等待 SW1 被按下
                                    // SW1_GetValue() 在 pin_manager.h 裡宣告
    LCD_Set_Cursor(0,0);
    putrsLCD ("Key In :         "); // 顯示 "Key In :        "
    LCD_Set_Cursor(1,0);
    putrsLCD(Disp_Line[3]);         // 顯示 "Time =          "
    
    Timer_Counter = 0 ;
    LCD_Update = 0 ;
    SW_Input = 0x00;
    LCD_Course = 8;

    while(1)
    {
        if (SW_Input != 0x00) 
        { 
                LCD_Set_Cursor(0,LCD_Course++);
                putcLCD(SW_Input);
                SW_Input = 0x00;
                if (LCD_Course >= 16)
                {   
                    LCD_Course = 8;
                    LCD_Set_Cursor(0,LCD_Course);
                }              
        }
        
        if (LCD_Update)             // 檢查一秒的計時到了嗎?
        {                           // 是，一秒已到，更新 LCD 的顯示
        LCD_Update = 0;
        LCD_Set_Cursor(1,7);        // LCD 游標移到第二行第八個位置
        putsLCD (itoa(Disp_String,Timer_Counter,10)); // 顯示經轉換後的字串資料
        putcLCD(' ');               // 顯示單個 ASCII Code 字元
        putcLCD('s');
        putcLCD('e');
        putcLCD('c');
        Timer_Counter ++;           // 計數器加一
        }
  
    }
}


void Key_Scan(void)
{
	if (debounce == 0)					// Do it need to debounce processing?
	{
		if (!SW1_GetValue()) 				// No need to debounce, Checking the key status
		{
			SW_Input = '1';
			debounce = 10;
		}	
                if (!SW2_GetValue()) 
		{
			SW_Input = '2';
			debounce = 10;
		}
	}
	else
	{
		if (!SW1_GetValue()|!SW2_GetValue()) debounce = 10;    	// check all key have released
		else debounce--;
	}

}
/**
 End of File
*/